@@ -26,6 +26,9 @@ from rabbitpy import utils
 
 LOGGER = logging.getLogger(__name__)
 
+AMQP = 'amqp'
+AMQPS = 'amqps'
+
 if ssl:
     SSL_CERT_MAP = {'ignore': ssl.CERT_NONE,
                     'optional': ssl.CERT_OPTIONAL,
@@ -120,17 +123,9 @@ class Connection(base.StatefulObject):
         it's an exception or what.
 
         """
-        if DEBUG:
-            LOGGER.debug('In __exit__ (%s, %s)', exc_type, exc_val)
-
         if exc_type:
-            if DEBUG:
-                LOGGER.debug('Connection context manager closed on %s '
-                             'exception', exc_type, exc_info=True)
-            LOGGER.info('Shutting down connection on unhandled exception')
-            self._shutdown_connection()
-            if exc_type != KeyboardInterrupt:
-                raise exc_type(exc_val)
+            LOGGER.error('Shutting down connection on unhandled exception: %s',
+                         exc_type)
         self.close()
 
     @property
@@ -169,10 +164,6 @@ class Connection(base.StatefulObject):
         if not self.closed:
             self._set_state(self.CLOSING)
 
-            # Close any channels if they're open
-            if self._channels:
-                self._close_channels()
-
             # Shutdown the IO thread and socket
             self._shutdown_connection()
 
@@ -425,8 +416,8 @@ class Connection(base.StatefulObject):
             use_ssl = False
 
         # Use the default ports if one is not specified
-        port = parsed.port or (self.PORTS['amqps'] if parsed.scheme == 'amqps'
-                               else self.PORTS['amqp'])
+        port = parsed.port or (self.PORTS[AMQPS] if parsed.scheme == AMQPS
+                               else self.PORTS[AMQP])
 
         # Set the vhost to be after the base slash if it was specified
         vhost = parsed.path[1:] if parsed.path else self.DEFAULT_VHOST
@@ -465,7 +456,9 @@ class Connection(base.StatefulObject):
                 LOGGER.debug('Cant shutdown connection, IO is no longer alive')
             return
 
-        for chan_id in self._channels:
+        # Close any open channels
+        for chan_id in [chan_id for chan_id in self._channels
+                        if not self._channels[chan_id].closed]:
             self._channels[chan_id].close()
 
         # If the connection is still established, close it
