@@ -37,7 +37,7 @@ class IOLoop(object):
     ERROR = 0x008 | 0x010
 
     def __init__(self, fd, error_callback, read_callback, write_queue,
-                 event_obj, write_trigger):
+                 event_obj, write_trigger, exceptions):
         self._data = threading.local()
         self._data.fd = fd
         self._data.error_callback = error_callback
@@ -48,6 +48,7 @@ class IOLoop(object):
         self._data.ssl = hasattr(fd, 'read')
         self._data.events = event_obj
         self._data.write_trigger = write_trigger
+        self._exceptions = exceptions
 
         # Materialized lists for select
         self._data.read_only = [[fd, write_trigger], [], [fd], POLL_TIMEOUT]
@@ -59,8 +60,9 @@ class IOLoop(object):
             try:
                 self._poll()
             except (KeyboardInterrupt, SystemExit) as exception:
-                LOGGER.warning('Exiting IOLoop.run due to %s', exception)
-                break
+                LOGGER.error('Received %r', exception)
+                self._exceptions.put(exception)
+                pass
             except EnvironmentError as exception:
                 if (getattr(exception, 'errno', None) == errno.EINTR or
                     (isinstance(getattr(exception, 'args', None), tuple) and
@@ -164,6 +166,11 @@ class IO(threading.Thread, base.StatefulObject):
     CONNECTION_TIMEOUT = 3
     CONTENT_METHODS = ['Basic.Deliver', 'Basic.GetOk', 'Basic.Return']
     READ_BUFFER_SIZE = specification.FRAME_MAX_SIZE
+    SSL_KWARGS = {'keyfile': 'ssl_key',
+                  'certfile': 'ssl_cert',
+                  'cert_reqs': 'ssl_validation',
+                  'ssl_version': 'ssl_version',
+                  'cacerts': 'ssl_cacert'}
 
     def __init__(self, group=None, target=None, name=None, args=(),
                  kwargs=None):
@@ -357,15 +364,14 @@ class IO(threading.Thread, base.StatefulObject):
         """
         sock = socket.socket(af, socktype, proto)
         if self._args['ssl']:
+            kwargs = {'sock': sock,
+                      'server_side': False}
+            for argv, key in self.SSL_KWARGS.iteritems():
+                if self._args[key]:
+                    kwargs[argv] = self._args[key]
             if DEBUG:
-                LOGGER.debug('Wrapping socket for SSL')
-            return ssl.wrap_socket(sock,
-                                   self._args['ssl_key'],
-                                   self._args['ssl_cert'],
-                                   False,
-                                   self._args['ssl_validation'],
-                                   self._args['ssl_version'],
-                                   self._args['ssl_cacert'])
+                LOGGER.debug('Wrapping socket for SSL: %r', kwargs)
+            return ssl.wrap_socket(**kwargs)
         return sock
 
     def _disconnect_socket(self):
@@ -458,7 +464,8 @@ class IO(threading.Thread, base.StatefulObject):
         self._loop = IOLoop(self._socket, self.on_error, self.on_read,
                             self._write_queue,
                             self._events,
-                            self._write_listener)
+                            self._write_listener,
+                            self._exceptions)
         self._loop.run()
 
     def _socketpair(self):
